@@ -5,11 +5,10 @@
 #include <gmodule.h>
 
 #include "crux-draw.h"
-#include "crux-common.h"
 
 G_BEGIN_DECLS
 
-extern GType crux_type_style G_GNUC_INTERNAL;
+extern GType crux_type_style;
 
 #define CRUX_TYPE_STYLE              crux_type_style
 #define CRUX_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), CRUX_TYPE_STYLE, CruxStyle))
@@ -32,7 +31,7 @@ struct _CruxStyleClass
 
 };
 
-void crux_style_register_type (GTypeModule *module) G_GNUC_INTERNAL;
+void crux_style_register_type (GTypeModule *module);
 
 G_END_DECLS
 
