@@ -29,6 +29,8 @@
 #ifndef SMOOTH_GTK_RC_H
 #define SMOOTH_GTK_RC_H
 
+#include "ge-support.h"
+
 #define SMOOTH_EDGE_NONE		1
 #define SMOOTH_EDGE_LINE		2
 #define SMOOTH_EDGE_GRADIENT		3
@@ -212,6 +214,7 @@ typedef struct {
 typedef struct {
   smooth_part_style part;
 
+  gboolean highlight;
   gboolean use_active_tab;
 
   smooth_part_style active_tab;
@@ -280,6 +283,7 @@ enum
 
     TOKEN_TABS,
     TOKEN_ACTIVE_TAB,
+    TOKEN_HIGHLIGHT,
 
     TOKEN_PROGRESS,
     
@@ -315,8 +319,8 @@ enum
     TOKEN_LAST = TOKEN_DEPRECATED_GRADIENT
   };
 
-extern ThemeSymbols theme_symbols[] G_GNUC_INTERNAL;
-extern guint n_theme_symbols G_GNUC_INTERNAL;
+extern ThemeSymbols theme_symbols[];
+extern guint n_theme_symbols;
 
 /* fill part */
 gint smooth_fill_style(GtkStyle * style, void *part) G_GNUC_INTERNAL;
