@@ -53,165 +53,6 @@
 #include "smooth_gtk2_drawing.h"
 #include "smooth_gtk2_misc.h"
 
-/* Widget Type Lookups/Macros */
-gboolean
-object_is_a (gpointer object, gchar * type_name)
-{
-  gboolean result = FALSE;
-
-  if ((object))
-    {
-      GType tmp = g_type_from_name (type_name);
-      if (tmp)
-	result = g_type_check_instance_is_a ((GTypeInstance * )object, tmp);
-    }
-
-  return result;
-}
-
-gboolean
-is_toolbar_item (GtkWidget * widget)
-{
-  gboolean result = FALSE;
-
-  if ((widget) && (widget->parent)) {
-    if ((IS_BONOBO_TOOLBAR (widget->parent))
-	|| (IS_BONOBO_DOCK_ITEM (widget->parent))
-	|| (IS_EGG_TOOLBAR (widget->parent))
-	|| (GTK_IS_TOOLBAR (widget->parent))
-	|| (GTK_IS_HANDLE_BOX (widget->parent)))
-      result = TRUE;
-    else
-      result = is_toolbar_item (widget->parent);
-  }
-  return result;
-}
-
-gboolean
-is_panel_widget_item (GtkWidget * widget)
-{
-  gboolean result = FALSE;
-
-  if ((widget) && (widget->parent))
-    {
-      if (IS_PANEL_WIDGET (widget->parent))
-	result = TRUE;
-      else
-	result = is_panel_widget_item (widget->parent);
-    }
-  return result;
-}
-
-static GtkWidget *
-find_combo_box_entry_widget (GtkWidget * widget)
-{
-  GtkWidget *result = NULL;
-
-  if (widget)
-    {
-      if (IS_COMBO_BOX_ENTRY (widget))
-	result = widget;
-      else
-	result = find_combo_box_entry_widget (widget->parent);
-    }
-
-  return result;
-}
-
-static gboolean
-combo_box_is_using_list (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (IS_COMBO_BOX (widget)))
-    {
-      gboolean *tmp = NULL;
- 
-      gtk_widget_style_get (widget, "appears-as-list", &result, NULL);
- 
-      if (tmp)
-	result = *tmp;
-    }
- 
-  return result;
-}
-
-static GtkWidget *
-find_combo_box_widget (GtkWidget * widget, gboolean as_list)
-{
-  GtkWidget *result = NULL;
- 
-  if (widget)
-    {
-      if (IS_COMBO_BOX (widget))
-        {
-          if (as_list)
-            result = (combo_box_is_using_list(widget))?widget:NULL;
-          else
-            result = (!combo_box_is_using_list(widget))?widget:NULL;
-        }
-      else
-	result = find_combo_box_widget (widget->parent, as_list);
-    }
-  return result;
-}
- 
-static GtkWidget *
-find_combo_widget (GtkWidget * widget)
-{
-  GtkWidget *result = NULL;
- 
-  if (widget)
-    {
-      if (IS_COMBO (widget))
-	result = widget;
-      else
-	result = find_combo_widget(widget->parent);
-    }
-  return result;
-}
-
-gboolean
-is_combo_box_entry (GtkWidget * widget)
-{
-  return (find_combo_box_entry_widget(widget) != NULL);
-}
-
-gboolean
-is_combo_box (GtkWidget * widget, gboolean as_list)
-{
-  return (find_combo_box_widget(widget, as_list) != NULL);
-}
- 
-gboolean
-is_combo (GtkWidget * widget)
-{
-  return (find_combo_widget(widget) != NULL);
-}
- 
-gboolean
-is_in_combo_box (GtkWidget * widget)
-{
-  return ((is_combo (widget) || is_combo_box (widget, TRUE) || is_combo_box_entry (widget)));
-}
-
-GtkWidget*
-get_combo_box_widget_parent (GtkWidget * widget)
-{
-   GtkWidget *result = NULL;
-   
-   if (!result)
-     result = find_combo_widget(widget);
-  
-   if (!result)
-     result = find_combo_box_widget(widget, TRUE);
-
-   if (!result)
-     result = find_combo_box_entry_widget(widget);
-
-  return result;
-}
-
 /* Misc Functions */
 GdkBitmap *
 arc_clip_mask(gint width,
@@ -451,7 +292,7 @@ reverse_engineer_arrow_box (GtkWidget    *widget,
       *height += 2;
       *x -= 1;
     }
-  else if ((is_in_combo_box (widget) || 
+  else if ((ge_is_in_combo_box (widget) || 
                IS_SPIN_BUTTON (widget)) && 
              ENTRY_BUTTON_EMBED(widget->style))
     {
@@ -474,40 +315,6 @@ reverse_engineer_arrow_box (GtkWidget    *widget,
   }  
 }
 
-static const GtkRequisition default_option_indicator_size = { 7, 13 };
-static const GtkBorder default_option_indicator_spacing = { 7, 5, 2, 2 };
-
-void
-option_menu_get_props (GtkWidget      *widget,
-		       GtkRequisition *indicator_size,
-		       GtkBorder      *indicator_spacing)
-{
-  GtkRequisition *tmp_size = NULL;
-  GtkBorder *tmp_spacing = NULL;
-  
-  if ((widget) && (IS_OPTION_MENU(widget)))
-    gtk_widget_style_get (widget, 
-			  "indicator_size", &tmp_size,
-			  "indicator_spacing", &tmp_spacing,
-			  NULL);
-
-  if (tmp_size)
-    {
-      *indicator_size = *tmp_size;
-      g_free (tmp_size);
-    }
-  else
-    *indicator_size = default_option_indicator_size;
-
-  if (tmp_spacing)
-    {
-      *indicator_spacing = *tmp_spacing;
-      g_free (tmp_spacing);
-    }
-  else
-    *indicator_spacing = default_option_indicator_spacing;
-}
-
 static const GtkBorder default_default_border = { 1, 1, 1, 1 };
 static const GtkBorder default_default_outside_border = { 0, 0, 0, 0 };
 
