@@ -505,7 +505,7 @@ cleanup_color_cache(SmoothBool Force)
 }
 
 static SmoothColor *
-internal_color_get_color(GdkColormap *Colormap, SmoothColor *_Color, SmoothDouble Shade,  SmoothInt index)
+smooth_internal_color_get_color(GdkColormap *Colormap, SmoothColor *_Color, SmoothDouble Shade,  SmoothInt index)
 {
 	GdkCachedColor *cache=NULL;
 	SmoothColor *result=NULL;
@@ -543,7 +543,7 @@ internal_color_get_color(GdkColormap *Colormap, SmoothColor *_Color, SmoothDoubl
 }
 
 static void
-internal_color_unref(SmoothInt index)
+smooth_internal_color_unref(SmoothInt index)
 {  
 	GdkCachedColor *cache = NULL;
 
@@ -566,7 +566,7 @@ internal_color_unref(SmoothInt index)
 }
 
 GdkGC *
-internal_drawing_area_use_pen_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool RequireValidColor)
+smooth_internal_drawing_area_use_pen_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool RequireValidColor)
 {
 	GdkGC *result = NULL;
 
@@ -586,7 +586,7 @@ internal_drawing_area_use_pen_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool Requ
 		{
 			SmoothColor *fg = NULL;
 
-			fg = internal_color_get_color(Canvas->Colormap, &Canvas->Pen.Color, 1.0, value);
+			fg = smooth_internal_color_get_color(Canvas->Colormap, &Canvas->Pen.Color, 1.0, value);
 			
 			gc_values.foreground = fg->RGB;
 			gc_values.background = fg->RGB;
@@ -637,8 +637,9 @@ internal_drawing_area_use_pen_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool Requ
 	return result;
 	
 }
+
 void
-internal_drawing_area_unuse_pen_gc(SmoothGDKPrivateCanvas *Canvas, GdkGC * GC)
+smooth_internal_drawing_area_unuse_pen_gc(SmoothGDKPrivateCanvas *Canvas, GdkGC * GC)
 {
 	if (Canvas)
 	{
@@ -651,13 +652,13 @@ internal_drawing_area_unuse_pen_gc(SmoothGDKPrivateCanvas *Canvas, GdkGC * GC)
 		
 		if ((value >= 0) && (Canvas->Pen.Color.Alpha > 0))
 		{
-			internal_color_unref(value);
+			smooth_internal_color_unref(value);
 		}
 	}	
 }
 
 GdkGC *
-internal_drawing_area_use_brush_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool RequireValidColor)
+smooth_internal_drawing_area_use_brush_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool RequireValidColor)
 {
 	GdkGC *result = NULL;
 
@@ -675,7 +676,7 @@ internal_drawing_area_use_brush_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool Re
 		{
 			SmoothColor *fg = NULL;
 
-			fg = internal_color_get_color(Canvas->Colormap, &Canvas->Brush.Color, 1.0, value);
+			fg = smooth_internal_color_get_color(Canvas->Colormap, &Canvas->Brush.Color, 1.0, value);
 			
 			gc_values.foreground = fg->RGB;
 			gc_values.background = fg->RGB;
@@ -690,8 +691,9 @@ internal_drawing_area_use_brush_gc(SmoothGDKPrivateCanvas *Canvas, SmoothBool Re
 	return result;
 	
 }
+
 void
-internal_drawing_area_unuse_brush_gc(SmoothGDKPrivateCanvas *Canvas, GdkGC * GC)
+smooth_internal_drawing_area_unuse_brush_gc(SmoothGDKPrivateCanvas *Canvas, GdkGC * GC)
 {
 	if (Canvas)
 	{
@@ -704,7 +706,7 @@ internal_drawing_area_unuse_brush_gc(SmoothGDKPrivateCanvas *Canvas, GdkGC * GC)
 	
 		if ((value >= 0) && (Canvas->Brush.Color.Alpha > 0))
 		{
-			internal_color_unref(value);
+			smooth_internal_color_unref(value);
 		}
 	}	
 }
@@ -724,7 +726,7 @@ GDKCanvasCacheShadedColor(SmoothGDKPrivateCanvas *Canvas,
 		{		
 			SmoothColor *tmp = NULL;
 
-			tmp = internal_color_get_color(Canvas->Colormap, &Base, Shade, -1);
+			tmp = smooth_internal_color_get_color(Canvas->Colormap, &Base, Shade, -1);
 		
 			if (tmp)
 			{
@@ -753,7 +755,7 @@ GDKCanvasUnCacheShadedColor(SmoothGDKPrivateCanvas *Canvas,
 	{
 		if (Base.Alpha > 0)
 		{		
-			internal_color_unref(_Color->CacheIndex);
+			smooth_internal_color_unref(_Color->CacheIndex);
 			_Color->CacheIndex = -1;
 		}	
 
@@ -783,7 +785,7 @@ GDKCanvasUnCacheColor(SmoothGDKPrivateCanvas *Canvas,
 		if (_Color->Alpha > 0)
 		{						
 		
-			internal_color_unref(_Color->CacheIndex);
+			smooth_internal_color_unref(_Color->CacheIndex);
 			_Color->CacheIndex = -1;
 		}
 		result = SmoothTrue;
